@@ -6,11 +6,11 @@ http://code.activestate.com/recipes/576694/
 """
 from __future__ import absolute_import, division, print_function
 
-import collections
+import collections.abc
 
 from .sixing import *
 
-class oset(collections.MutableSet):
+class oset(collections.abc.MutableSet):
     """
     Ordered Set, preserves order of entry in set
 
